==> qtjambi-qt3dinput-5.15.13-sources.jar: io/qt/qt3d/input/QAbstractAxisInput.java <==
package io.qt.qt3d.input;


/**
 * <p>QAbstractActionInput is the base class for all Axis Input</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dinput-qabstractaxisinput.html">Qt3DInput::QAbstractAxisInput</a></p>
 */
public class QAbstractAxisInput extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractAxisInput.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qabstractaxisinput.html#sourceDevice-prop">Qt3DInput::QAbstractAxisInput::sourceDeviceChanged(Qt3DInput::QAbstractPhysicalDevice*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="sourceDevice")
    public final Signal1<io.qt.qt3d.input.QAbstractPhysicalDevice> sourceDeviceChanged = new Signal1<>();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qabstractaxisinput.html#sourceDevice-prop">Qt3DInput::QAbstractAxisInput::setSourceDevice(Qt3DInput::QAbstractPhysicalDevice*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="sourceDevice")
    public final void setSourceDevice(io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice){
        setSourceDevice_native_Qt3DInput_QAbstractPhysicalDevice_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(sourceDevice));
    }
    
    private native void setSourceDevice_native_Qt3DInput_QAbstractPhysicalDevice_ptr(long __this__nativeId, long sourceDevice);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qabstractaxisinput.html#sourceDevice-prop">Qt3DInput::QAbstractAxisInput::sourceDevice()const</a></p>
     */
    @io.qt.QtPropertyReader(name="sourceDevice")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice(){
        return sourceDevice_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractAxisInput(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dinput-6.3.0-sources.jar: io/qt/qt3d/input/QAbstractAxisInput.java <==
package io.qt.qt3d.input;


/**
 * <p>QAbstractActionInput is the base class for all Axis Input</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3dinput-qabstractaxisinput.html">Qt3DInput::QAbstractAxisInput</a></p>
 */
public class QAbstractAxisInput extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractAxisInput.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qabstractaxisinput.html#sourceDevice-prop">Qt3DInput::QAbstractAxisInput::sourceDeviceChanged(Qt3DInput::QAbstractPhysicalDevice*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="sourceDevice")
    public final Signal1<io.qt.qt3d.input.QAbstractPhysicalDevice> sourceDeviceChanged = new Signal1<>();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qabstractaxisinput.html#sourceDevice-prop">Qt3DInput::QAbstractAxisInput::setSourceDevice(Qt3DInput::QAbstractPhysicalDevice*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="sourceDevice")
    public final void setSourceDevice(io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice){
        setSourceDevice_native_Qt3DInput_QAbstractPhysicalDevice_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(sourceDevice));
    }
    
    private native void setSourceDevice_native_Qt3DInput_QAbstractPhysicalDevice_ptr(long __this__nativeId, long sourceDevice);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qabstractaxisinput.html#sourceDevice-prop">Qt3DInput::QAbstractAxisInput::sourceDevice()const</a></p>
     */
    @io.qt.QtPropertyReader(name="sourceDevice")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice(){
        return sourceDevice_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractAxisInput(QPrivateConstructor p) { super(p); } 
    
}
